package com.yihu.ehr.svrinspection.controller;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.yihu.ehr.constants.ApiVersion;
import com.yihu.ehr.controller.BaseController;
import com.yihu.ehr.util.rest.Envelop;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 *  机构检验申请控制类
 *
 * @author HZY
 * @created 2018/11/9 16:23
 */
@RequestMapping(ApiVersion.Version1_0 + "/exam")
@RestController
@Api(value = "AssistanceApplyControllerDemo", description = "区域检验相关接口", tags = {"区域检验-demo"})
public class AssistanceApplyControllerDemo extends BaseController {

    @Autowired
    private ObjectMapper objectMapper;

    @GetMapping(value = "/area")
    @ApiOperation(value = "区域检验-【区域排行】")
    public Envelop examAreaRanking(
            @ApiParam(name = "eventDate", value = "就诊时间（年月）", defaultValue = "")
            @RequestParam(value = "eventDate", required = false) String eventDate) throws IOException {

        String demoData = "[{\"areaCode\":\"test\",\"areaName\":\"测试区域\",\"count\":100},{\"areaCode\":\"test2\",\"areaName\":\"测试区域2\",\"count\":100}]";
        List list = objectMapper.readValue(demoData,List.class);
        return success(list);
    }

    @GetMapping(value = "/hospital")
    @ApiOperation(value = "区域检验-【医院排行】")
    public Envelop examHospitalRanking(
            @ApiParam(name = "areaCode", value = "区域编码", defaultValue = "")
            @RequestParam(value = "areaCode", required = false) String areaCode,
            @ApiParam(name = "eventDate", value = "就诊时间（年月）", defaultValue = "")
            @RequestParam(value = "eventDate", required = false) String eventDate) throws IOException {

        String demoData = "[{\"orgCode\":\"test1\",\"orgName\":\"测试机构1\",\"count\":100},{\"orgCode\":\"test2\",\"orgName\":\"测试机构2\",\"count\":100}]";
        List list = objectMapper.readValue(demoData,List.class);
        return success(list);
    }

    @GetMapping(value = "/statistics")
    @ApiOperation(value = "区域检验-【统计信息】")
    public Envelop statistics(
            @ApiParam(name = "orgCode", value = "机构编码（不传默认全市）", defaultValue = "")
            @RequestParam(value = "orgCode", required = false) String orgCode,
            @ApiParam(name = "date", value = "日期", defaultValue = "")
            @RequestParam(value = "date", required = false) String date) throws IOException {

        String demoData = "{\"total\":10000,\"increase\":200,\"applied\":100,\"solution\":100,\"eventPercentage\":{\"clinic\":20,\"resident\":80}}";
        Map<String,Object> map = objectMapper.readValue(demoData,Map.class);
        return success(map);
    }


    @GetMapping(value = "/organizations/statistics")
    @ApiOperation(value = "机构今日检验统计查询")
    public Envelop orgStatistics(
            @ApiParam(name = "orgCode", value = "机构编码（不传默认全市）", defaultValue = "")
            @RequestParam(value = "orgCode", required = false) String orgCode) throws IOException {

        String demoData = "{\"increase\":200,\"waitSolution\":100,\"solution\":100}";
        Map<String,Object> map = objectMapper.readValue(demoData,Map.class);
        return success(map);
    }

    @GetMapping(value = "/apply/list")
    @ApiOperation(value = "机构申请/处理列表查询")
    public Envelop applyList(
            @ApiParam(name = "orgCode", value = "机构编码")
            @RequestParam(value = "orgCode", required = false) String orgCode,
            @ApiParam(name = "orgDept", value = "科室编码（不传默认查找所有）")
            @RequestParam(value = "orgDept", required = false) String orgDept,
            @ApiParam(name = "type", value = "检查：HDSD00_79,检验：HDSD00_77（不传默认查找所有）")
            @RequestParam(value = "type", required = false) String type,
            @ApiParam(name = "patientName", value = "患者姓名")
            @RequestParam(value = "patientName", required = false) String patientName,
            @ApiParam(name = "startDate", value = "起始时间 ",defaultValue = "2018-06-12 12:00:00")
            @RequestParam(value = "startDate", required = false) String startDate,
            @ApiParam(name = "endDate", value = "终止时间", required = true, defaultValue = "2018-09-12 12:00:00")
            @RequestParam(value = "endDate") String endDate,
            @ApiParam(name = "page", value = "页码", required = true,defaultValue = "1")
            @RequestParam(value = "page") Integer page,
            @ApiParam(name = "size", value = "分页大小", required = true,defaultValue = "20")
            @RequestParam(value = "size") Integer size) throws IOException {

        String demoData = "[{\"id\":1,\"applyOrg\":\"test1\",\"applyUserId\":\"0001xa\",\"applyDate\":\"2018-08-28 08:44:13\",\"remark\":\"申请人附加备注\",\"picture\":\"group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.jpg,group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.png\",\"isRead\":\"0\",\"solutionOrg\":\"jkzl\",\"solutionStatus\":\"0\",\"solutionDate\":\"2018-08-28 08:44:13\",\"solutionReply\":\"处理人回复内容\",\"profileId\":\"000333333333331\",\"examType\":\"hdsd00_77\",\"examDept\":\"011s\",\"examItemName\":\"项目名称（冗余）\",\"patientName\":\"病人徐明明（冗余）\",\"patientAge\":\"16岁（冗余）\",\"patientSex\":\"1\"},{\"Id\":2,\"applyOrg\":\"test2\",\"applyUserId\":\"0001xa\",\"applyDate\":\"2018-08-28 08:44:13\",\"remark\":\"申请人附加备注\",\"picture\":\"group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.jpg,group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.png\",\"isRead\":\"0\",\"solutionOrg\":\"jkzl\",\"solutionStatus\":\"0\",\"solutionDate\":\"2018-08-28 08:44:13\",\"solutionReply\":\"处理人回复内容1\",\"profileId\":\"000333333333331\",\"examType\":\"hdsd00_77\",\"examDept\":\"0112\",\"examItemName\":\"项目名称（冗余）\",\"patientName\":\"病人徐明明（冗余）\",\"patientAge\":\"16岁（冗余）\",\"patientSex\":\"1\"}]";
        List list = objectMapper.readValue(demoData,List.class);
        return success(list);
    }

    @GetMapping(value = "/apply/detail")
    @ApiOperation(value = "下级机构申请详情-查看")
    public Envelop applyDetail(
            @ApiParam(name = "applyId", value = "申请记录ID")
            @RequestParam(value = "applyId", required = false) String applyId) throws IOException {

        String demoData = "{\"id\":1,\"applyOrg\":\"test1\",\"applyUserId\":\"0001xa\",\"applyDate\":\"2018-08-28 08:44:13\",\"remark\":\"申请人附加备注\",\"picture\":\"group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.jpg,group1:M00/3F/F9/wKgyJVsP0niAKmoUAAAI4qVePDY281.png\",\"isRead\":\"0\",\"solutionOrg\":\"jkzl\",\"solutionStatus\":\"0\",\"solutionDate\":\"2018-08-28 08:44:13\",\"solutionReply\":\"处理人回复内容\",\"profileId\":\"000333333333331\",\"examType\":\"hdsd00_77\",\"examDept\":\"011s\",\"examItemName\":\"项目名称（冗余）\",\"patientName\":\"病人徐明明（冗余）\",\"patientAge\":\"16岁（冗余）\",\"patientSex\":\"1\"}";
        Map<String,Object> map = objectMapper.readValue(demoData,Map.class);
        return success(map);
    }



}
